@@ -2336,7 +2336,7 @@ int manifest_crosslink(int rid, Blob *pContent, int flags){
   int parentid = 0;
   int permitHooks = (flags & MC_PERMIT_HOOKS);
   const char *zScript = 0;
-  const char *zUuid = 0;
+  char *zUuid = 0;
 
   if( g.fSqlTrace ){
     fossil_trace("-- manifest_crosslink(%d)\n", rid);
@@ -2372,7 +2372,7 @@ int manifest_crosslink(int rid, Blob *pContent, int flags){
   if( p->type==CFTYPE_MANIFEST ){
     if( permitHooks ){
       zScript = xfer_commit_code();
-      zUuid = db_text(0, "SELECT uuid FROM blob WHERE rid=%d", rid);
+      zUuid = rid_to_uuid(rid);
     }
     if( p->nCherrypick && db_table_exists("repository","cherrypick") ){
       int i;
@@ -2724,7 +2724,8 @@ int manifest_crosslink(int rid, Blob *pContent, int flags){
             " WHERE event.type='ci' AND event.objid=blob.rid"
             " AND blob.uuid=%Q", zTagUuid) ){
           zScript = xfer_commit_code();
-          zUuid = zTagUuid;
+          fossil_free(zUuid);
+          zUuid = fossil_strdup(zTagUuid);
         }
       }
       zName = p->aTag[i].zName;
@@ -2807,6 +2808,8 @@ int manifest_crosslink(int rid, Blob *pContent, int flags){
     int froot, fprev, firt;
     char *zFType;
     char *zTitle;
+
+    assert( 0==zUuid );
     schema_forum();
     search_doc_touch('f', rid, 0);
     froot = p->zThreadRoot ? uuid_to_rid(p->zThreadRoot, 1) : rid;
@@ -2879,6 +2882,7 @@ int manifest_crosslink(int rid, Blob *pContent, int flags){
       rc = xfer_run_script(zScript, zUuid, 0);
     }
   }
+  fossil_free(zUuid);
   if( p->type==CFTYPE_MANIFEST ){
     manifest_cache_insert(p);
   }else{
